@@ -21,3 +21,22 @@ Facter.add("netmask") do
     Facter::NetMask.get_netmask
   end
 end
+
+Facter.add(:netmask) do
+  confine :kernel => :windows
+  setcode do
+    require 'facter/util/ip/windows'
+
+    mask = nil
+
+    adapters = Facter::Util::IP::Windows.get_preferred_ipv4_adapters
+    adapters.find do |nic|
+      nic.IPSubnet.any? do |subnet|
+        mask = subnet if Facter::Util::IP::Windows.valid_ipv4_address?(subnet)
+        mask
+      end
+    end
+
+    mask
+  end
+end
