@@ -141,7 +141,7 @@ end
 Facter.add(:operatingsystemrelease) do
   confine :operatingsystem => %w{VMwareESX}
   setcode do
-    release = Facter::Util::Resolution.exec('vmware -v')
+    release = Facter::Core::Execution.exec('vmware -v')
     if match = /VMware ESX .*?(\d.*)/.match(release)
       match[1]
     end
@@ -181,13 +181,51 @@ Facter.add(:operatingsystemrelease) do
   setcode do
     if release = Facter::Util::FileRead.read('/etc/release')
       line = release.split("\n").first.chomp
+      # Solaris 10: Solaris 10 10/09 s10x_u8wos_08a X86
+      # Solaris 11 (old naming scheme): Oracle Solaris 11 11/11 X86
+      # Solaris 11 (new naming scheme): Oracle Solaris 11.1 SPARC
       if match = /\s+s(\d+)[sx]?(_u\d+)?.*(?:SPARC|X86)/.match(line)
         match.captures.join('')
+      elsif match = /Solaris ([0-9\.]+(?:\s*[0-9\.\/]+))\s*(?:SPARC|X86)/.match(line)
+        match.captures[0]
       end
     end
   end
 end
 
+Facter.add(:operatingsystemrelease) do
+  confine :operatingsystem => :windows
+  setcode do
+    require 'facter/util/wmi'
+    result = nil
+    Facter::Util::WMI.execquery("SELECT version, producttype FROM Win32_OperatingSystem").each do |os|
+      result =
+        case os.version
+        when /^6\.2/
+          os.producttype == 1 ? "8" : "2012"
+        when /^6\.1/
+          os.producttype == 1 ? "7" : "2008 R2"
+        when /^6\.0/
+          os.producttype == 1 ? "Vista" : "2008"
+        when /^5\.2/
+          if os.producttype == 1
+            "XP"
+          else
+            begin
+              os.othertypedescription == "R2" ? "2003 R2" : "2003"
+            rescue NoMethodError
+              "2003"
+            end
+          end
+        else
+          Facter[:kernelrelease].value
+        end
+      break
+    end
+    result
+  end
+end
+
 Facter.add(:operatingsystemrelease) do
   setcode do Facter[:kernelrelease].value end
 end
