@@ -22,8 +22,9 @@
 require 'thread'
 require 'facter/util/processor'
 
-## We have to enumerate these outside a Facter.add block to get the processorN descriptions iteratively
-## (but we need them inside the Facter.add block above for tests on processorcount to work)
+# We have to enumerate these outside a Facter.add block to get the processorN
+# descriptions iteratively (but we need them inside the Facter.add block above
+# for tests on processorcount to work)
 processor_list = case Facter::Util::Processor.kernel_fact_value
 when "AIX"
   Facter::Util::Processor.aix_processor_list
@@ -90,21 +91,21 @@ end
 Facter.add("Processor") do
   confine :kernel => :openbsd
   setcode do
-    Facter::Util::Resolution.exec("uname -p")
+    Facter::Core::Execution.exec("uname -p")
   end
 end
 
 Facter.add("ProcessorCount") do
   confine :kernel => :openbsd
   setcode do
-    Facter::Util::Resolution.exec("sysctl -n hw.ncpu")
+    Facter::Core::Execution.exec("sysctl -n hw.ncpu")
   end
 end
 
 Facter.add("ProcessorCount") do
   confine :kernel => :Darwin
   setcode do
-    Facter::Util::Resolution.exec("sysctl -n hw.ncpu")
+    Facter::Core::Execution.exec("sysctl -n hw.ncpu")
   end
 end
 
@@ -117,9 +118,9 @@ if Facter.value(:kernel) == "windows"
     # get each physical processor
     Facter::Util::WMI.execquery("select * from Win32_Processor").each do |proc|
       # not supported before 2008
-      begin
+      if proc.respond_to?(:NumberOfLogicalProcessors)
         processor_num = proc.NumberOfLogicalProcessors
-      rescue RuntimeError => e
+      else
         processor_num = 1
       end
 
@@ -149,14 +150,14 @@ end
 Facter.add("Processor") do
   confine :kernel => [:dragonfly,:freebsd]
   setcode do
-    Facter::Util::Resolution.exec("sysctl -n hw.model")
+    Facter::Core::Execution.exec("sysctl -n hw.model")
   end
 end
 
 Facter.add("ProcessorCount") do
   confine :kernel => [:dragonfly,:freebsd]
   setcode do
-    Facter::Util::Resolution.exec("sysctl -n hw.ncpu")
+    Facter::Core::Execution.exec("sysctl -n hw.ncpu")
   end
 end
 
@@ -168,15 +169,15 @@ Facter.add("ProcessorCount") do
     result = nil
 
     if (major_version > 5) or (major_version == 5 and minor_version >= 8) then
-      if kstat = Facter::Util::Resolution.exec("/usr/bin/kstat cpu_info")
+      if kstat = Facter::Core::Execution.exec("/usr/bin/kstat cpu_info")
         result = kstat.scan(/\bcore_id\b\s+\d+/).uniq.length
       end
     else
-      if output = Facter::Util::Resolution.exec("/usr/sbin/psrinfo") then
+      if output = Facter::Core::Execution.exec("/usr/sbin/psrinfo") then
         result = output.split("\n").length
       end
     end
 
-    result
+    result.to_s
   end
 end
