@@ -55,7 +55,7 @@ module Facter::Manufacturer
       Facter.add(facterkey) do
         confine :kernel => [:openbsd, :darwin]
         setcode do
-          Facter::Util::Resolution.exec("sysctl -n #{sysctlkey} 2>/dev/null")
+          Facter::Core::Execution.exec("sysctl -n #{sysctlkey} 2>/dev/null")
         end
       end
     end
@@ -63,7 +63,7 @@ module Facter::Manufacturer
 
   def self.prtdiag_sparc_find_system_info()
     # Parses prtdiag for a SPARC architecture string, won't work with Solaris x86
-    output = Facter::Util::Resolution.exec('/usr/sbin/prtdiag 2>/dev/null')
+    output = Facter::Core::Execution.exec('/usr/sbin/prtdiag 2>/dev/null')
 
     # System Configuration:  Sun Microsystems  sun4u Sun SPARC Enterprise M3000 Server
     if output and output =~ /^System Configuration:\s+(.+?)\s+(sun\d+\S+)\s+(.+)/
@@ -81,7 +81,7 @@ module Facter::Manufacturer
 
     Facter.add('serialnumber') do
       setcode do
-        Facter::Util::Resolution.exec("/usr/sbin/sneep")
+        Facter::Core::Execution.exec("/usr/sbin/sneep")
       end
     end
   end
