@@ -48,7 +48,7 @@ describe "Memory facts" do
     before(:each) do
       Facter.clear
       Facter.fact(:kernel).stubs(:value).returns("Darwin")
-      Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.memsize').returns('8589934592')
+      Facter::Core::Execution.stubs(:exec).with('sysctl -n hw.memsize').returns('8589934592')
       sample_vm_stat = <<VMSTAT
 Mach Virtual Memory Statistics: (page size of 4096 bytes)
 Pages free:                          28430.
@@ -64,8 +64,8 @@ Pageins:                          13862917.
 Pageouts:                          1384383.
 Object cache: 14 hits of 2619925 lookups (0% hit rate)
 VMSTAT
-      Facter::Util::Resolution.stubs(:exec).with('vm_stat').returns(sample_vm_stat)
-      Facter::Util::Resolution.stubs(:exec).with('sysctl vm.swapusage').returns("vm.swapusage: total = 64.00M  used = 1.00M  free = 63.00M  (encrypted)")
+      Facter::Core::Execution.stubs(:exec).with('vm_stat').returns(sample_vm_stat)
+      Facter::Core::Execution.stubs(:exec).with('sysctl vm.swapusage').returns("vm.swapusage: total = 64.00M  used = 1.00M  free = 63.00M  (encrypted)")
 
       Facter.collection.internal_loader.load(:memory)
     end
@@ -154,7 +154,7 @@ device maj,min total free
 /dev/hd6 10, 2 512MB 508MB
 SWAP
 
-      Facter::Util::Resolution.stubs(:exec).with('swap -l 2>/dev/null').returns(swapusage)
+      Facter::Core::Execution.stubs(:exec).with('swap -l 2>/dev/null').returns(swapusage)
 
       svmon = <<SVMON
 Unit: KB
@@ -168,7 +168,7 @@ pin         1478228           0           0      953852
 in use      4448928           0     5499480
 SVMON
 
-      Facter::Util::Resolution.stubs(:exec).with('/usr/bin/svmon -O unit=KB').returns(svmon)
+      Facter::Core::Execution.stubs(:exec).with('/usr/bin/svmon -O unit=KB').returns(svmon)
 
       Facter.collection.internal_loader.load(:memory)
     end
@@ -222,16 +222,16 @@ SVMON
       Facter.fact(:kernel).stubs(:value).returns("OpenBSD")
 
       swapusage = "total: 148342k bytes allocated = 0k used, 148342k available"
-      Facter::Util::Resolution.stubs(:exec).with('swapctl -s').returns(swapusage)
+      Facter::Core::Execution.stubs(:exec).with('swapctl -s').returns(swapusage)
 
       vmstat = <<EOS
  procs  memory     page          disks  traps      cpu
  r b w  avm   fre  flt  re  pi  po  fr  sr cd0 sd0  int   sys   cs us sy id
  0 0 0  11048  181028   39   0   0   0   0   0   0   1  3  90   17  0  0 100
 EOS
-      Facter::Util::Resolution.stubs(:exec).with('vmstat').returns(vmstat)
+      Facter::Core::Execution.stubs(:exec).with('vmstat').returns(vmstat)
 
-      Facter::Util::Resolution.stubs(:exec).with("sysctl hw.physmem | cut -d'=' -f2").returns('267321344')
+      Facter::Core::Execution.stubs(:exec).with("sysctl hw.physmem | cut -d'=' -f2").returns('267321344')
 
       Facter.collection.internal_loader.load(:memory)
     end
@@ -267,14 +267,14 @@ Memory size: 2048 Megabytes
 System Peripherals (Software Nodes):
 
 PRTCONF
-      Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/prtconf 2>/dev/null').returns sample_prtconf
+      Facter::Core::Execution.stubs(:exec).with('/usr/sbin/prtconf 2>/dev/null').returns sample_prtconf
 
       vmstat_lines = <<VMSTAT
  kthr      memory            page            disk          faults      cpu
  r b w   swap  free  re  mf pi po fr de sr s0 s3 -- --   in   sy   cs us sy id
  0 0 0 1154552 476224 8  19  0  0  0  0  0  0  0  0  0  460  294  236  1  2 97
 VMSTAT
-      Facter::Util::Resolution.stubs(:exec).with('vmstat').returns(vmstat_lines)
+      Facter::Core::Execution.stubs(:exec).with('vmstat').returns(vmstat_lines)
     end
 
     after(:each) do
@@ -287,7 +287,7 @@ VMSTAT
 swapfile             dev  swaplo blocks   free
 /dev/swap           4294967295,4294967295     16 2097136 2097136
 SWAP
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
+        Facter::Core::Execution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
 
         Facter.collection.internal_loader.load(:memory)
       end
@@ -316,7 +316,7 @@ swapfile             dev  swaplo blocks   free
 /dev/swap           4294967295,4294967295     16 2097136 2097136
 /dev/swap2          4294967295,4294967295     16 2097136 2097136
 SWAP
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
+        Facter::Core::Execution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns sample_swap_line
         Facter.collection.internal_loader.load(:memory)
       end
 
@@ -339,7 +339,7 @@ SWAP
 
     describe "when no swap exists" do
       before(:each) do
-        Facter::Util::Resolution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns ""
+        Facter::Core::Execution.stubs(:exec).with('/usr/sbin/swap -l 2>/dev/null').returns ""
 
         Facter.collection.internal_loader.load(:memory)
       end
@@ -368,19 +368,19 @@ SWAP
         Facter.fact(:kernel).stubs(:value).returns("dragonfly")
 
         swapusage = "total: 148342k bytes allocated = 0k used, 148342k available"
-        Facter::Util::Resolution.stubs(:exec).with('/sbin/sysctl -n hw.pagesize').returns("4096")
-        Facter::Util::Resolution.stubs(:exec).with('/sbin/sysctl -n vm.swap_size').returns("128461")
-        Facter::Util::Resolution.stubs(:exec).with('/sbin/sysctl -n vm.swap_anon_use').returns("2635")
-        Facter::Util::Resolution.stubs(:exec).with('/sbin/sysctl -n vm.swap_cache_use').returns("0")
+        Facter::Core::Execution.stubs(:exec).with('/sbin/sysctl -n hw.pagesize').returns("4096")
+        Facter::Core::Execution.stubs(:exec).with('/sbin/sysctl -n vm.swap_size').returns("128461")
+        Facter::Core::Execution.stubs(:exec).with('/sbin/sysctl -n vm.swap_anon_use').returns("2635")
+        Facter::Core::Execution.stubs(:exec).with('/sbin/sysctl -n vm.swap_cache_use').returns("0")
 
         vmstat = <<EOS
  procs    memory    page          disks   faults    cpu
  r b w   avm  fre  flt  re  pi  po  fr  sr da0 sg1   in   sy  cs us sy id
  0 0 0   33152  13940 1902120 2198 53119 11642 6544597 5460994   0   0 6148243 7087927 3484264  0  1 9
 EOS
-        Facter::Util::Resolution.stubs(:exec).with('vmstat').returns(vmstat)
+        Facter::Core::Execution.stubs(:exec).with('vmstat').returns(vmstat)
 
-        Facter::Util::Resolution.stubs(:exec).with("sysctl -n hw.physmem").returns('248512512')
+        Facter::Core::Execution.stubs(:exec).with("sysctl -n hw.physmem").returns('248512512')
 
         Facter.collection.internal_loader.load(:memory)
       end
@@ -416,11 +416,11 @@ EOS
  r b w     avm    fre   flt  re  pi  po    fr  sr da0 cd0   in   sy   cs us sy id
  1 0 0  207600  656640    10   0   0   0    13   0   0   0   51  164  257  0  1 99
 VM_STAT
-        Facter::Util::Resolution.stubs(:exec).with('vmstat -H').returns sample_vmstat
+        Facter::Core::Execution.stubs(:exec).with('vmstat -H').returns sample_vmstat
         sample_physmem = <<PHYSMEM
 1056276480
 PHYSMEM
-        Facter::Util::Resolution.stubs(:exec).with('sysctl -n hw.physmem').returns sample_physmem
+        Facter::Core::Execution.stubs(:exec).with('sysctl -n hw.physmem').returns sample_physmem
       end
 
       after(:each) do
@@ -432,7 +432,7 @@ PHYSMEM
           sample_swapinfo = <<SWAP
 Device          1K-blocks     Used    Avail Capacity
 SWAP
-          Facter::Util::Resolution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
+          Facter::Core::Execution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
 
           Facter.collection.internal_loader.load(:memory)
         end
@@ -460,7 +460,7 @@ SWAP
 Device          1K-blocks     Used    Avail Capacity
 /dev/da0p3        2048540        0  1048540     0%
 SWAP
-          Facter::Util::Resolution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
+          Facter::Core::Execution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
 
           Facter.collection.internal_loader.load(:memory)
         end
@@ -489,7 +489,7 @@ Device          1K-blocks     Used    Avail Capacity
 /dev/da0p3        2048540        0  1048540     0%
 /dev/da0p4        3048540        0  1048540     0%
 SWAP
-          Facter::Util::Resolution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
+          Facter::Core::Execution.stubs(:exec).with('swapinfo -k').returns sample_swapinfo
 
           Facter.collection.internal_loader.load(:memory)
         end
@@ -534,13 +534,6 @@ SWAP
         Facter::Util::WMI.stubs(:execquery).returns([computer])
 
         Facter.fact(:memorysize_mb).value.should == '3999.55'
-        Facter.fact(:MemoryTotal).value.should == '3.91 GB'
     end
   end
-
-  it "should use the memorysize fact for the memorytotal fact" do
-    Facter.fact("memorysize").expects(:value).once.returns "16.00 GB"
-    Facter::Util::Resolution.expects(:exec).never
-    Facter.fact(:memorytotal).value.should == "16.00 GB"
-  end
 end
