@@ -18,14 +18,14 @@ describe Facter::Manufacturer do
   end
 
   it "should parse prtdiag output on a sunfire v120" do
-    Facter::Util::Resolution.stubs(:exec).returns(my_fixture_read("solaris_sunfire_v120_prtdiag"))
+    Facter::Core::Execution.stubs(:exec).returns(my_fixture_read("solaris_sunfire_v120_prtdiag"))
     Facter::Manufacturer.prtdiag_sparc_find_system_info()
     Facter.value(:manufacturer).should == "Sun Microsystems"
     Facter.value(:productname).should == "Sun Fire V120 (UltraSPARC-IIe 648MHz)"
   end
 
   it "should parse prtdiag output on a t5220" do
-    Facter::Util::Resolution.stubs(:exec).returns(my_fixture_read("solaris_t5220_prtdiag"))
+    Facter::Core::Execution.stubs(:exec).returns(my_fixture_read("solaris_t5220_prtdiag"))
     Facter::Manufacturer.prtdiag_sparc_find_system_info()
     Facter.value(:manufacturer).should == "Sun Microsystems"
     Facter.value(:productname).should == "SPARC Enterprise T5220"
@@ -36,7 +36,7 @@ describe Facter::Manufacturer do
     Facter.fact(:kernel).stubs(:value).returns("SunOS")
     Facter.fact(:hardwareisa).stubs(:value).returns("sparc")
 
-    Facter::Util::Resolution.stubs(:exec).with(regexp_matches(/prtdiag/)).returns(nil)
+    Facter::Core::Execution.stubs(:exec).with(regexp_matches(/prtdiag/)).returns(nil)
     Facter::Manufacturer.prtdiag_sparc_find_system_info()
     Facter.value(:manufacturer).should_not == "Sun Microsystems"
   end
