@@ -1,4 +1,4 @@
-#!/usr/bin/env rspec
+#! /usr/bin/env ruby
 
 require 'spec_helper'
 require 'facter'
@@ -7,7 +7,7 @@ describe "zonename fact" do
 
   it "should return global zone" do
     Facter.fact(:kernel).stubs(:value).returns("SunOS")
-    Facter::Util::Resolution.stubs(:exec).with("zonename").returns('global')
+    Facter::Core::Execution.stubs(:exec).with("zonename", anything).returns('global')
 
     Facter.fact(:zonename).value.should == "global"
   end
